@@ -62,7 +62,7 @@ import javax.mail.MessagingException;
 import javax.mail.NoSuchProviderException;
 import javax.mail.Session;
 import javax.mail.Store;
-import javax.mail.internet.IDNA;
+import javax.mail.internet.idn.IDNA;
 import javax.security.auth.login.LoginException;
 import org.apache.commons.logging.Log;
 import com.openexchange.authentication.Authenticated;
@@ -224,13 +224,13 @@ public class IMAPAuthentication implements AuthenticationService {
             boolean USE_IMAPS = false;
             if ("true".equalsIgnoreCase(props.getProperty(PropertyNames.USE_MULTIPLE.name))) {
 	            final ContextService contextService = getServiceRegistry().getService(ContextService.class, true);
-	
+
 	            final int ctxId = contextService.getContextId(splitted[0]);
 	            if (ContextStorage.NOT_FOUND == ctxId) {
 	                throw INVALID_CREDENTIALS.create();
 	            }
 	            final Context ctx = contextService.getContext(ctxId);
-	
+
 	            final UserService userService = getServiceRegistry().getService(UserService.class, true);
 	            final int userId;
 	            try {
@@ -239,7 +239,7 @@ public class IMAPAuthentication implements AuthenticationService {
 	                throw INVALID_CREDENTIALS.create();
 	            }
 	            // final User user2 = userService.getUser(userId, ctx);
-	            
+
 	            /*
 	             * Load primary account and check its protocol to be IMAP
 	             */
@@ -251,7 +251,7 @@ public class IMAPAuthentication implements AuthenticationService {
 	                    "IMAP authentication failed: Primary account's protocol is not IMAP but ").append(mailProtocol).append(
 	                    " for user ").append(userId).append(" in context ").append(ctxId).toString());
 	            }
-	
+
 	            /*
 	             * Set user according to configured login source if different from LoginSource.USER_NAME
 	             */
@@ -262,7 +262,7 @@ public class IMAPAuthentication implements AuthenticationService {
 	            if (LoginSource.PRIMARY_EMAIL.equals(loginSource)) {
 	                user = defaultMailAccount.getPrimaryAddress();
 	            }
-	
+
 	            /*
 	             * Get IMAP server from primary account
 	             */
@@ -400,7 +400,7 @@ public class IMAPAuthentication implements AuthenticationService {
 
     /**
      * Splits user name and context.
-     * 
+     *
      * @param loginInfo combined information separated by an @ sign.
      * @return a string array with context and user name (in this order).
      */
@@ -410,7 +410,7 @@ public class IMAPAuthentication implements AuthenticationService {
 
     /**
      * Splits user name and context.
-     * 
+     *
      * @param loginInfo combined information separated by an @ sign.
      * @param separator for splitting user name and context.
      * @return a string array with context and user name (in this order).
